pub enum DrawReason {
Stalemate,
InsufficientMaterial,
ThreefoldRepetition,
FiftyMoveRule,
Agreement,
}Expand description
Represents the reason for a draw
Variants
Stalemate: The game is a stalemateInsufficientMaterial: The game is a draw due to insufficient materialThreefoldRepetition: The game is a draw due to threefold repetitionFiftyMoveRule: The game is a draw due to the fifty move ruleAgreement: The game is a draw due to agreement
Variants