PgnLine

Struct PgnLine 

pub struct PgnLine<T: PartialEq + Clone + Display> {
    pub lines: Vec<Rc<RefCell<PgnLine<T>>>>,
    pub parent: Option<Rc<RefCell<PgnLine<T>>>>,
    pub halfmove_clock: u32,
    pub fullmove_number: u32,
    pub en_passant: Option<Position>,
    pub castling_rights: u8,
    pub game_status: GameStatus,
    pub mov: T,
}
A struct representing a PGN line or variation Its also a tree node that contains a list of child nodes, the parent node, the move number and the move itself

Fields

lines: Vec<Rc<RefCell<PgnLine<T>>>>parent: Option<Rc<RefCell<PgnLine<T>>>>halfmove_clock: u32fullmove_number: u32en_passant: Option<Position>castling_rights: u8game_status: GameStatusmov: T