Module core

Module core 

Module containing core chess logic and data structures

Structs

Move
Represents a move in a chess game
MoveInfo
Represents the information of a Move
PGNTree
A struct representing a PGN tree It contains the game metadata and a list of lines The current line is the move node that is currently being checked
Piece
Represents a piece on the board with a color and a piece type
Position
Represents a position on the board. The position is represented by a column and a row.

Enums

CastleType
Represents the side of the board to castle on
Color
Represents the color of a chess Piece
DrawReason
Represents the reason for a draw
GameStatus
Represents the status of a chess game
MoveType
Represents the type of a Move
PieceType
Represents the type of a chess piece
WinReason
Represents winning reasons

Traits

Variant
A trait for a chess variant.
VariantBuilder
Construction helpers for variant types.

Functions

piece_movement
Returns the movement function for a given piece type