pub enum DrawReason {
Stalemate,
InsufficientMaterial,
ThreefoldRepetition,
FiftyMoveRule,
Agreement,
}Expand description
Represents the reason for a draw
Variants
Stalemate
The Game is a stalemate
InsufficientMaterial
The Game is a draw due to insufficient material
ThreefoldRepetition
The Game is a draw due to threefold repetition
FiftyMoveRule
The Game is a draw due to the fifty move rule
Agreement
The Game is a draw due to agreement