pub struct PGNTree<T: PartialEq + Clone + Display + Debug> {
pub event: String,
pub site: String,
pub date: String,
pub round: String,
pub white: String,
pub black: String,
pub result: String,
pub variant: Option<String>,
/* private fields */
}Expand description
A struct representing a PGN tree It contains the game metadata and a list of lines The current line is the move node that is currently being checked
Fields
event: StringThe event name
site: StringThe site name
date: StringThe date of the game
round: StringThe round number
white: StringThe white player name
black: StringThe black player name
result: StringThe result of the game
variant: Option<String>The variant of the game
Implementations
Sourceimpl<T: PartialEq + Clone + Display + Debug> PGNTree<T>
impl<T: PartialEq + Clone + Display + Debug> PGNTree<T>
Sourcepub fn new(
event: String,
site: String,
date: String,
round: String,
white: String,
black: String,
result: String,
variant: Option<String>,
) -> PGNTree<T> ⓘ
pub fn new( event: String, site: String, date: String, round: String, white: String, black: String, result: String, variant: Option<String>, ) -> PGNTree<T> ⓘ
Creates a new PGNTree with the provided metadata and an empty list of lines
Arguments
event: The event namesite: The site namedate: The date of the gameround: The round numberwhite: The white player nameblack: The black player nameresult: The result of the gamevariant: The variant of the gamewhite_elo: The white player ELOblack_elo: The black player ELOtime_control: The time control of the game
Returns
A new PGNTree
Examples
use chess_lab::core::{PGNTree, Move};
let tree: PGNTree<Move> = PGNTree::new(
"Event".to_string(),
"Site".to_string(),
"Date".to_string(),
"Round".to_string(),
"White".to_string(),
"Black".to_string(),
"Result".to_string(),
None,
);Sourcepub fn add_metadata(
&mut self,
key: &str,
value: &str,
) -> Result<(), PGNMetadataError>
pub fn add_metadata( &mut self, key: &str, value: &str, ) -> Result<(), PGNMetadataError>
Adds metadata to the PGNTree
Arguments
key: The metadata keyvalue: The metadata value
Returns
A Result<(), PGNMetadataError>
Ok(()): If the metadata was added successfullyErr(PGNMetadataError): If the metadata key is invalid
Examples
use chess_lab::core::{PGNTree, Move};
let mut tree: PGNTree<Move> = PGNTree::default();
tree.add_metadata("Event", "My Event").unwrap();
assert_eq!(tree.event, "My Event");Sourcepub fn add_move(
&mut self,
mov: T,
halfmove_clock: u32,
fullmove_number: u32,
en_passant: Option<Position>,
castling_rights: u8,
game_status: GameStatus,
prev_positions: HashMap<String, u32>,
)
pub fn add_move( &mut self, mov: T, halfmove_clock: u32, fullmove_number: u32, en_passant: Option<Position>, castling_rights: u8, game_status: GameStatus, prev_positions: HashMap<String, u32>, )
Adds a move to the current line
Arguments
mov: The move to addhalfmove_clock: The halfmove clockfullmove_number: The fullmove numberen_passant: The en passant positioncastling_rights: The castling rightsgame_status: The game statusprev_positions: The previous positions
Examples
use chess_lab::core::{PGNTree, Piece, Move, MoveType, PieceType, Color, Position, GameStatus};
use std::collections::HashMap;
let mut pgn_tree: PGNTree<Move> = PGNTree::default();
let mov = Move::new(
Piece::new(Color::Black, PieceType::Pawn),
Position::from_string("e2").unwrap(),
Position::from_string("e4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
pgn_tree.add_move(mov.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
assert_eq!(mov, pgn_tree.get_move().unwrap());Sourcepub fn rm_move(&mut self)
pub fn rm_move(&mut self)
Removes the current line
Examples
use chess_lab::core::{PGNTree, Piece, Move, PieceType, MoveType, Color, Position, GameStatus};
use std::collections::HashMap;
let mut tree = PGNTree::default();
tree.add_move(Move::new(
Piece::new(Color::Black, PieceType::Pawn),
Position::from_string("e2").unwrap(),
Position::from_string("e4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
tree.rm_move();Sourcepub fn get_move(&self) -> Option<T>
pub fn get_move(&self) -> Option<T>
Returns the current move
Returns
The current move
Examples
use chess_lab::core::{PGNTree, Piece, Move, PieceType, MoveType, Color, Position, GameStatus};
use std::collections::HashMap;
let mut tree = PGNTree::default();
let mov = Move::new(
Piece::new(Color::Black, PieceType::Pawn),
Position::from_string("e2").unwrap(),
Position::from_string("e4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
tree.add_move(mov.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
assert_eq!(tree.get_move(), Some(mov));Sourcepub fn get_move_info(&self) -> Option<MoveInfo>
pub fn get_move_info(&self) -> Option<MoveInfo>
Returns the move info
Returns
A tuple containing the halfmove clock, the fullmove number, the en passant position and the castling rights
Examples
use chess_lab::core::{PGNTree, Piece, Move, PieceType, MoveType, Color, Position, GameStatus, MoveInfo};
use std::collections::HashMap;
let mut tree = PGNTree::default();
let mov = Move::new(
Piece::new(Color::Black, PieceType::Pawn),
Position::from_string("e2").unwrap(),
Position::from_string("e4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
tree.add_move(mov.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
assert_eq!(tree.get_move_info(), Some(MoveInfo::new(0, 0, None, 0, GameStatus::InProgress, HashMap::new())));Sourcepub fn next_move(&mut self) -> Option<T>
pub fn next_move(&mut self) -> Option<T>
Returns the next move
Returns
The next move
Examples
use chess_lab::core::{PGNTree, Piece, Move, PieceType, MoveType, Color, Position, GameStatus};
use std::collections::HashMap;
let mut pgn_tree = PGNTree::default();
let mov1 = Move::new(
Piece::new(Color::Black, PieceType::Pawn),
Position::from_string("e2").unwrap(),
Position::from_string("e4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
let mov2 = Move::new(
Piece::new(Color::White, PieceType::Pawn),
Position::from_string("e7").unwrap(),
Position::from_string("e5").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
pgn_tree.add_move(mov1.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
pgn_tree.add_move(mov2.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
assert_eq!(mov2, pgn_tree.get_move().unwrap());
assert_eq!(mov1, pgn_tree.prev_move().unwrap());
assert_eq!(mov2, pgn_tree.next_move().unwrap());Sourcepub fn next_move_variant(&mut self, variant: u32) -> Option<T>
pub fn next_move_variant(&mut self, variant: u32) -> Option<T>
Returns the next move variant
Arguments
variant: The variant to get
Returns
The next move variant
Examples
use chess_lab::core::{PGNTree, Piece, Move, PieceType, MoveType, Color, Position, GameStatus};
use std::collections::HashMap;
let mut pgn_tree = PGNTree::default();
let mov1 = Move::new(
Piece::new(Color::White, PieceType::Pawn),
Position::from_string("e2").unwrap(),
Position::from_string("e4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
let mov2 = Move::new(
Piece::new(Color::White, PieceType::Pawn),
Position::from_string("d2").unwrap(),
Position::from_string("d4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
pgn_tree.add_move(mov1.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
pgn_tree.prev_move();
pgn_tree.add_move(mov2.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
pgn_tree.prev_move();
assert_eq!(mov1, pgn_tree.next_move().unwrap());
pgn_tree.prev_move();
assert_eq!(mov2, pgn_tree.next_move_variant(1).unwrap());Sourcepub fn all_next_moves(&self) -> Vec<T>
pub fn all_next_moves(&self) -> Vec<T>
Returns all the next moves
Returns
All the next moves
Example
use chess_lab::core::{PGNTree, Piece, Move, PieceType, MoveType, Color, Position, GameStatus};
use std::collections::HashMap;
let mut pgn_tree = PGNTree::default();
let mov1 = Move::new(
Piece::new(Color::White, PieceType::Pawn),
Position::from_string("e4").unwrap(),
Position::from_string("e2").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
let mov2 = Move::new(
Piece::new(Color::White, PieceType::Pawn),
Position::from_string("d2").unwrap(),
Position::from_string("d4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
pgn_tree.add_move(mov1.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
pgn_tree.prev_move();
pgn_tree.add_move(mov2.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
pgn_tree.prev_move();
assert_eq!(vec![mov1.clone(), mov2.clone()], pgn_tree.all_next_moves());Sourcepub fn prev_move(&mut self) -> Option<T>
pub fn prev_move(&mut self) -> Option<T>
Returns the previous move
Returns
The previous move
Examples
use chess_lab::core::{PGNTree, Piece, Move, PieceType, MoveType, Color, Position, GameStatus};
use std::collections::HashMap;
let mut pgn_tree = PGNTree::default();
let mov1 = Move::new(
Piece::new(Color::Black, PieceType::Pawn),
Position::from_string("e2").unwrap(),
Position::from_string("e4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
). unwrap();
let mov2 = Move::new(
Piece::new(Color::White, PieceType::Pawn),
Position::from_string("e7").unwrap(),
Position::from_string("e5").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
pgn_tree.add_move(mov1.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
pgn_tree.add_move(mov2.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
assert_eq!(mov2, pgn_tree.get_move().unwrap());
assert_eq!(mov1, pgn_tree.prev_move().unwrap());Sourcepub fn has_next_move(&self) -> bool
pub fn has_next_move(&self) -> bool
Returns whether there is a next move
Returns
Whether there is a next move
Examples
use chess_lab::core::{PGNTree, Piece, Move, PieceType, MoveType, Color, Position, GameStatus};
use std::collections::HashMap;
let mut pgn_tree = PGNTree::default();
let mov1 = Move::new(
Piece::new(Color::White, PieceType::Pawn),
Position::from_string("e2").unwrap(),
Position::from_string("e4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
pgn_tree.add_move(mov1.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
pgn_tree.prev_move();
assert!(pgn_tree.has_next_move());Sourcepub fn has_prev_move(&self) -> bool
pub fn has_prev_move(&self) -> bool
Returns whether there is a previous move
Returns
Whether there is a previous move
Examples
use chess_lab::core::{PGNTree, Piece, Move, PieceType, MoveType, Color, Position, GameStatus};
use std::collections::HashMap;
let mut pgn_tree = PGNTree::default();
let mov1 = Move::new(
Piece::new(Color::White, PieceType::Pawn),
Position::from_string("e2").unwrap(),
Position::from_string("e4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
pgn_tree.add_move(mov1.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
assert!(pgn_tree.has_prev_move());Sourcepub fn pgn(&self) -> String
pub fn pgn(&self) -> String
Returns the PGN of the game
Returns
The PGN of the game
Examples
use chess_lab::core::{PGNTree, Piece, Move, PieceType, MoveType, Color, Position, GameStatus};
use std::collections::HashMap;
let mut pgn_tree = PGNTree::default();
let mov1 = Move::new(
Piece::new(Color::White, PieceType::Pawn),
Position::from_string("e2").unwrap(),
Position::from_string("e4").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
let mov2 = Move::new(
Piece::new(Color::Black, PieceType::Pawn),
Position::from_string("e7").unwrap(),
Position::from_string("e5").unwrap(),
MoveType::Normal {
capture: false,
promotion: None,
},
None,
None,
(false, false),
false,
false,
).unwrap();
pgn_tree.add_move(mov1.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
pgn_tree.add_move(mov2.clone(), 0, 0, None, 0, GameStatus::InProgress, HashMap::new());
assert_eq!(pgn_tree.pgn(), "[Event \"\"]\n[Site \"\"]\n[Date \"\"]\n[Round \"\"]\n[White \"\"]\n[Black \"\"]\n[Result \"\"]\n1. e4 e5");Sourcepub fn game_over(&mut self, game_status: GameStatus)
pub fn game_over(&mut self, game_status: GameStatus)