Module errors

Module errors 

Module containing error types and handling mechanisms

Structs

Chess960SPIDError
An error that occurs when an invalid Chess960 Starting Position ID is encountered
FenError
An error that occurs when parsing a FEN string
MoveInfoError
Errors that can occur when trying to move a Piece
PGNMetadataError
An error that occurs when parsing PGN metadata
PieceReprError
An error that occurs when an invalid piece representation is encountered
PositionEmptyError
Error indicating that a specific Position is empty
PositionInvalidError
Error indicating that a Position is invalid
PositionOccupiedError
Error indicating that a specific Position is already occupied
PositionOutOfRangeError
Error indicating that a Position is out of the allowed range
UnalignedPositionsError
Error indicating that two Positions are not aligned

Enums

MoveError
Errors that can occur when trying to move a Piece
PGNError
An error that occurs when parsing a PGN string
PositionBetweenError
Error types for Position between operations