Board

Struct Board 

pub struct Board { /* private fields */ }
A struct that represents a chess board The board is represented by bitboards of each piece (color and type)

Implementations

Source

impl Board

pub fn new(fen: &str) -> Result<Board, FenError>

Creates a new board from a FEN string

Arguments
  • fen: A FEN string representing the board
Returns
  • Ok(Board): A new board with the position represented by the FEN string
  • Err(FenError): If the FEN string is invalid
pub fn empty() -> Board

Creates a new empty board

Returns

A new empty board

pub fn from_fen(fen: &str) -> Result<Board, FenError>

Creates a new board from a FEN string

Arguments
  • fen: A FEN string representing the board
Returns

A Result<Board, FenError> object

  • Ok(Board): A new board with the position represented by the FEN string
  • Err(FenError): If the FEN string is invalid
pub fn is_ocupied(&self, pos: &Position) -> bool

Checks if a position is occupied by a piece

Arguments
  • pos: The position to check
Returns

Whether the position is occupied by a piece

pub fn get_piece(&self, pos: &Position) -> Option<Piece>

Gets the piece at a position

Arguments
  • pos: The position to get the piece
Returns

The piece at the position or None if the position is empty

pub fn set_piece( &mut self, piece: Piece, pos: &Position, ) -> Result<(), PositionOccupiedError>

Sets a piece at a position

Arguments
  • piece: The piece to set
  • pos: The position to set the piece
Returns
  • Ok(()): If the piece was set successfully
  • Err(PositionOccupiedError): If the position is already occupied
pub fn delete_piece( &mut self, pos: &Position, ) -> Result<Piece, PositionEmptyError>

Deletes a piece at a position

Arguments
  • pos: The position to delete the piece
Returns
  • Ok(Piece): The piece that was deleted
  • Err(PositionEmptyError): If the position is empty
pub fn find(&self, piece_type: PieceType, color: Color) -> Vec<Position>

Finds all pieces of a certain type and color

Arguments
  • piece_type: The type of the piece
  • color: The color of the piece
Returns

A vector of positions of the pieces

pub fn find_all(&self, color: Color) -> Vec<Position>

Finds all pieces of a certain color

Arguments
  • color: The color of the pieces
Returns

A vector of positions of the pieces

pub fn move_piece( &mut self, from: &Position, to: &Position, ) -> Result<(), PositionEmptyError>

Moves a piece from one position to another

Arguments
  • from: The position to move the piece from
  • to: The position to move the piece to
Returns
  • Ok(()): If the piece was moved successfully
  • Err(PositionEmptyError): If the start position is empty
pub fn is_attacked(&self, pos: Position, color: Color) -> bool

Checks if a position is attacked by a certain color

Arguments
  • pos: The position to check
  • color: The color of the attacking pieces
Returns

Whether the position is attacked or not

pub fn can_move( &self, start_pos: &Position, end_pos: &Position, ) -> Result<bool, PositionEmptyError>

Checks if a piece can move without considering checks

Arguments
  • start_pos: The position of the piece to move
  • end_pos: The position of the piece to capture
Returns
  • Ok(bool): Whether the piece can move acording to its movement rules
  • Err(PositionEmptyError): If the start position is empty
pub fn is_attacking( &self, start_pos: &Position, end_pos: &Position, ) -> Result<bool, PositionEmptyError>

Checks if a piece of a postion is attacking a position The function does not check if the move is legal It only checks if the piece is attacking the position according to its movement rules

Arguments
  • start_pos: The position of the piece to move
  • end_pos: The position of the piece to capture
Returns
  • Ok(bool): Whether the piece is attacking the position
  • Err(PositionEmptyError): If the start position is empty
pub fn piece_between( &self, from: &Position, to: &Position, ) -> Result<bool, PositionBetweenError>

Checks if there is a piece between two positions

Arguments
  • from: The starting position
  • to: The ending position
Returns
  • Ok(bool): Whether there is a piece between the two positions
  • Err(PositionBetweenError): If the positions are not aligned