Chess960

Struct Chess960 

pub struct Chess960 { /* private fields */ }
Chess960 is a variant of chess that uses the same rules as standard chess, but the starting position of the pieces is randomized.

Attributes

  • game - The Game struct that contains the current state of the game