StandardChess

Struct StandardChess 

pub struct StandardChess { /* private fields */ }
Standard Chess Variant This Variant is the most common chess variant played worldwide It is played on an 8x8 board with the following pieces for each player:

  • 8 Pawns
  • 2 Rooks
  • 2 Knights
  • 2 Bishops
  • 1 Queen
  • 1 King

The game is won by checkmating the opponent’s king The game is drawn by stalemate, threefold repetition, the fifty-move rule, or agreement The game is lost by resigning or losing on time

Attributes

  • game - The game struct that holds the state of the game