Module containing error types and handling mechanisms
Structs
- Chess960SPID
Error - An error that occurs when an invalid Chess960 Starting Position ID is encountered
- FenError
- An error that occurs when parsing a FEN string
- Move
Info Error - Errors that can occur when trying to move a Piece
- PGNMetadata
Error - An error that occurs when parsing PGN metadata
- Piece
Repr Error - An error that occurs when an invalid piece representation is encountered
- Position
Empty Error - Error indicating that a specific Position is empty
- Position
Invalid Error - Error indicating that a Position is invalid
- Position
Occupied Error - Error indicating that a specific Position is already occupied
- Position
OutOf Range Error - Error indicating that a Position is out of the allowed range
- Unaligned
Positions Error - Error indicating that two Positions are not aligned
Enums
- Move
Error - Errors that can occur when trying to move a Piece
- PGNError
- An error that occurs when parsing a PGN string
- Position
Between Error - Error types for Position between operations